Uses of Class org.openqa.selenium.server.browserlaunchers.FirefoxCustomProfileLauncher.FileLockRemainedException (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.browserlaunchers.FirefoxCustomProfileLauncher.FileLockRemainedException

Packages that use FirefoxCustomProfileLauncher.FileLockRemainedException
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.

Uses of FirefoxCustomProfileLauncher.FileLockRemainedException in org.openqa.selenium.server.browserlaunchers

Methods in org.openqa.selenium.server.browserlaunchers that throw FirefoxCustomProfileLauncher.FileLockRemainedException
`protected void` | `FirefoxCustomProfileLauncher.killFirefoxProcess()` Wrapper to allow for stubbed-out testing

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.